@@ -25,7 +25,7 @@ class Match:
 
     def run(self):
         for i, seed in enumerate(self._valid_seeds):
-            print(f"------------- Game {i} -------------")
+            print(f"------------- Game {i}/{len(self._valid_seeds)} -------------")
             try:
                 hider = self._HiderClass()
             except Exception as e:
